inspire_me: Get some data storytelling inspiration

Description Usage Arguments Value

View source: R/inspire_me.R

Description

This functions returns a random URL of data storytelling inspiration based on our contributed list. Users can specify author, affiliation, topic, or type if they wish. If open = TRUE and the session is interactive, then the URL will be opened in the user's browser.

Usage

1
inspire_me(author = "", affiliation = "", topic = "", type = "", open = FALSE)

Arguments

author

optional parameter to specify desired author of returned content

affiliation

optional parameter to specify desired affiliation of content

topic

optional parameter to specify desired topic of returned content

type

optional parameter to specify desired type of returned content

open

whether to open the URL in a browser. Defaults to FALSE

Value

A URL


sastoudt/inspiRe documentation built on Dec. 22, 2021, 10:17 p.m.