Description Usage Arguments Value
This functions returns a random URL of data storytelling inspiration based on our contributed list. Users can specify author, affiliation, topic, or type if they wish. If open = TRUE and the session is interactive, then the URL will be opened in the user's browser.
1 | inspire_me(author = "", affiliation = "", topic = "", type = "", open = FALSE)
|
author |
optional parameter to specify desired author of returned content |
affiliation |
optional parameter to specify desired affiliation of content |
topic |
optional parameter to specify desired topic of returned content |
type |
optional parameter to specify desired type of returned content |
open |
whether to open the URL in a browser. Defaults to |
A URL
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.